@@ -3,9 +3,9 @@ use std::rc::Weak;
 use std::{error, fmt, mem, ptr, slice};
 use widestring::U16CString;
 use windows::{
-    core::Interface,
+    core::{Interface, PCSTR},
     Win32::Devices::Properties::{DEVPKEY_Device_DeviceDesc, DEVPKEY_Device_FriendlyName},
-    Win32::Foundation::{HANDLE, PSTR},
+    Win32::Foundation::HANDLE,
     Win32::Media::Audio::{
         eCapture, eConsole, eRender, AudioSessionStateActive, AudioSessionStateExpired,
         AudioSessionStateInactive, IAudioCaptureClient, IAudioClient, IAudioClock,
@@ -172,7 +172,7 @@ impl Device {
         unsafe {
             self.device.Activate(
                 &IAudioClient::IID,
-                CLSCTX_ALL.0,
+                CLSCTX_ALL,
                 ptr::null_mut(),
                 audio_client.as_mut_ptr() as *mut _,
             )?;
@@ -193,7 +193,7 @@ impl Device {
 
     /// Read the FriendlyName of an IMMDevice
     pub fn get_friendlyname(&self) -> WasapiRes<String> {
-        let store = unsafe { self.device.OpenPropertyStore(STGM_READ as u32)? };
+        let store = unsafe { self.device.OpenPropertyStore(STGM_READ)? };
         let prop = unsafe { store.GetValue(&DEVPKEY_Device_FriendlyName)? };
         let propstr = unsafe { PropVariantToStringAlloc(&prop)? };
         let wide_name = unsafe { U16CString::from_ptr_str(propstr.0) };
@@ -204,7 +204,7 @@ impl Device {
 
     /// Read the Description of an IMMDevice
     pub fn get_description(&self) -> WasapiRes<String> {
-        let store = unsafe { self.device.OpenPropertyStore(STGM_READ as u32)? };
+        let store = unsafe { self.device.OpenPropertyStore(STGM_READ)? };
         let prop = unsafe { store.GetValue(&DEVPKEY_Device_DeviceDesc)? };
         let propstr = unsafe { PropVariantToStringAlloc(&prop)? };
         let wide_desc = unsafe { U16CString::from_ptr_str(propstr.0) };
@@ -355,7 +355,7 @@ impl AudioClient {
 
     /// Create and return an event handle for an IAudioClient
     pub fn set_get_eventhandle(&self) -> WasapiRes<Handle> {
-        let h_event = unsafe { CreateEventA(std::ptr::null_mut(), false, false, PSTR::default()) };
+        let h_event = unsafe { CreateEventA(std::ptr::null_mut(), false, false, PCSTR::default()) };
         unsafe { self.client.SetEventHandle(h_event)? };
         Ok(Handle { handle: h_event })
     }
